/* See LICENSE file for copyright and license details. */

/* appearance */
static const unsigned int borderpx  = 2;        /* border pixel of windows */
static const unsigned int snap      = 32;       /* snap pixel */
static const int showbar            = 1;        /* 0 means no bar */
static const int topbar             = 1;        /* 0 means bottom bar */
static const char *fonts[]          = { "monospace:pixelsize=12:antialias=true:autohint=true" };

static const char col_black[]       = "#000000";
static const char col_darkgray[]    = "#101010";
static const char *const col_wired[] = {
	"#C3B495",
	"#CC838C",
	"#B66578",
	"#824856"
};
static const char *colors[][3] = {
	/*               fg         bg         border   */
	[SchemeNorm] = {col_wired[1], col_black, col_wired[0]},
	[SchemeSel] = {col_wired[1], col_darkgray, col_wired[2]},
};

/* tagging */
static const char *tags[] = { "■", "●", "▲", "◆"};

static const Rule rules[] = {
	/* xprop(1):
	 *	WM_CLASS(STRING) = instance, class
	 *	WM_NAME(STRING) = title
	 */
	/* class    instance    title       tags mask     isfloating   iskeyboard     monitor */
	{ "svkbd",  NULL,       NULL,       0,            False,       True,         -1 },
};

/* layout(s) */
static const float mfact     = 0.55; /* factor of master area size [0.05..0.95] */
static const int nmaster     = 1;    /* number of clients in master area */
static const int resizehints = 0;    /* 1 means respect size hints in tiled resizals */

static const Layout layouts[] = {
	/* symbol     arrange function */
	{ "[_]",      mobilefocus },    /* first entry is default */
	{ "><>",      NULL },    /* no layout function means floating behavior */
};

/* key definitions */
#define MODKEY Mod1Mask
#define TAGKEYS(KEY,TAG) \
	{ 0, MODKEY,                       KEY,      view,           {.ui = 1 << TAG} }, \
	{ 0, MODKEY|ControlMask,           KEY,      toggleview,     {.ui = 1 << TAG} }, \
	{ 0, MODKEY|ShiftMask,             KEY,      tag,            {.ui = 1 << TAG} }, \
	{ 0, MODKEY|ControlMask|ShiftMask, KEY,      toggletag,      {.ui = 1 << TAG} },

/* helper for spawning shell commands in the pre dwm-5.0 fashion */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }
#define STCMD(cmd) { .v = (const char*[]){ "/usr/bin/st", "-e", cmd, NULL } }

/* commands */
static char dmenumon[2] = "0"; /* component of dmenucmd, manipulated in spawn() */
static const char *dmenucmd[] = { "dmenu_run", "-m", dmenumon, NULL };
static const char *termcmd[]  = { "st", NULL };
static const char *keycmd[]  = { "svkbd-mobile-intl", NULL };

#define MULTIKEY_THRESHOLD_MS_PRESS 500
#define MULTIKEY_THRESHOLD_MS_HOLD 1000

static Key keys[] = {
	/* modifier                     key        function        argument */
	{ 0, MODKEY,                       XK_p,      spawn,          {.v = dmenucmd } },
	{ 0, MODKEY|ShiftMask,             XK_Return, spawn,          {.v = termcmd } },
	{ 0, MODKEY,                       XK_b,      togglebar,      {0} },
	{ 0, MODKEY,                       XK_j,      focusstack,     {.i = +1 } },
	{ 0, MODKEY,                       XK_k,      focusstack,     {.i = -1 } },
	{ 0, MODKEY,                       XK_i,      incnmaster,     {.i = +1 } },
	{ 0, MODKEY,                       XK_d,      incnmaster,     {.i = -1 } },
	{ 0, MODKEY,                       XK_h,      setmfact,       {.f = -0.05} },
	{ 0, MODKEY,                       XK_l,      setmfact,       {.f = +0.05} },
	{ 0, MODKEY,                       XK_Return, zoom,           {0} },
	{ 0, MODKEY,                       XK_Tab,    view,           {0} },
	{ 1, 0,                            XF86XK_PowerOff,      killclient,     {0} },
	{ 2, 0,                            XF86XK_PowerOff,      spawn,          {.v = keycmd } },
	{ 0, MODKEY,                       XK_t,      setlayout,      {.v = &layouts[0]} },
	{ 0, MODKEY,                       XK_f,      setlayout,      {.v = &layouts[1]} },
	{ 0, MODKEY,                       XK_m,      setlayout,      {.v = &layouts[2]} },
	{ 0, MODKEY,                       XK_space,  setlayout,      {0} },
	{ 0, MODKEY|ShiftMask,             XK_space,  togglefloating, {0} },
	{ 0, MODKEY,                       XK_0,      view,           {.ui = ~0 } },
	{ 0, MODKEY|ShiftMask,             XK_0,      tag,            {.ui = ~0 } },
	{ 0, MODKEY,                       XK_comma,  focusmon,       {.i = -1 } },
	{ 0, MODKEY,                       XK_period, focusmon,       {.i = +1 } },
	{ 0, MODKEY|ShiftMask,             XK_comma,  tagmon,         {.i = -1 } },
	{ 0, MODKEY|ShiftMask,             XK_period, tagmon,         {.i = +1 } },
	TAGKEYS(                        XK_1,                      0)
	TAGKEYS(                        XK_2,                      1)
	TAGKEYS(                        XK_3,                      2)
	TAGKEYS(                        XK_4,                      3)
	{ 0, MODKEY|ShiftMask,             XK_q,      quit,           {0} },
};

/* button definitions */
/* click can be ClkTagBar, ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static Button buttons[] = {
	/* click                event mask      button          function        argument */
	{ ClkLtSymbol,          0,              Button1,        setlayout,      {0} },
	{ ClkLtSymbol,          0,              Button3,        setlayout,      {.v = &layouts[2]} },
	{ ClkWinTitle,          0,              Button2,        zoom,           {0} },
	{ ClkStatusText,        0,              Button2,        spawn,          {.v = termcmd } },
	{ ClkClientWin,         MODKEY,         Button1,        movemouse,      {0} },
	{ ClkClientWin,         MODKEY,         Button2,        togglefloating, {0} },
	{ ClkClientWin,         MODKEY,         Button3,        resizemouse,    {0} },
	{ ClkTagBar,            0,              Button1,        view,           {0} },
	{ ClkTagBar,            0,              Button3,        toggleview,     {0} },
	{ ClkTagBar,            MODKEY,         Button1,        tag,            {0} },
	{ ClkTagBar,            MODKEY,         Button3,        toggletag,      {0} },
};

